==> zio-aws-ec2_2.12-5.17.130.5-sources.jar: zio/aws/ec2/model/LaunchTemplateHibernationOptions.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LaunchTemplateHibernationOptions(
    configured: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions = {
    import LaunchTemplateHibernationOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions
      .builder()
      .optionallyWith(configured.map(value => value: java.lang.Boolean))(
        _.configured
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LaunchTemplateHibernationOptions.ReadOnly =
    zio.aws.ec2.model.LaunchTemplateHibernationOptions.wrap(buildAwsValue())
}
object LaunchTemplateHibernationOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LaunchTemplateHibernationOptions =
      zio.aws.ec2.model
        .LaunchTemplateHibernationOptions(configured.map(value => value))
    def configured: Option[Boolean]
    def getConfigured: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("configured", configured)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions
  ) extends zio.aws.ec2.model.LaunchTemplateHibernationOptions.ReadOnly {
    override val configured: Option[Boolean] =
      scala.Option(impl.configured()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions
  ): zio.aws.ec2.model.LaunchTemplateHibernationOptions.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.295.22-sources.jar: zio/aws/ec2/model/LaunchTemplateHibernationOptions.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LaunchTemplateHibernationOptions(
    configured: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions = {
    import LaunchTemplateHibernationOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions
      .builder()
      .optionallyWith(configured.map(value => value: java.lang.Boolean))(
        _.configured
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LaunchTemplateHibernationOptions.ReadOnly =
    zio.aws.ec2.model.LaunchTemplateHibernationOptions.wrap(buildAwsValue())
}
object LaunchTemplateHibernationOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LaunchTemplateHibernationOptions =
      zio.aws.ec2.model
        .LaunchTemplateHibernationOptions(configured.map(value => value))
    def configured: Optional[Boolean]
    def getConfigured: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("configured", configured)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions
  ) extends zio.aws.ec2.model.LaunchTemplateHibernationOptions.ReadOnly {
    override val configured: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.configured())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateHibernationOptions
  ): zio.aws.ec2.model.LaunchTemplateHibernationOptions.ReadOnly = new Wrapper(
    impl
  )
}
